==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkDataObjectToDataSetFilter.java <==
// java wrapper for vtkDataObjectToDataSetFilter object
//

package vtk;
import vtk.*;

public class vtkDataObjectToDataSetFilter extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkDataObject GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDataSetType_3(int id0);
  public void SetDataSetType(int id0)
    { SetDataSetType_3(id0); }

  private native int GetDataSetType_4();
  public int GetDataSetType()
    { return GetDataSetType_4(); }

  private native void SetDataSetTypeToPolyData_5();
  public void SetDataSetTypeToPolyData()
    { SetDataSetTypeToPolyData_5(); }

  private native void SetDataSetTypeToStructuredPoints_6();
  public void SetDataSetTypeToStructuredPoints()
    { SetDataSetTypeToStructuredPoints_6(); }

  private native void SetDataSetTypeToStructuredGrid_7();
  public void SetDataSetTypeToStructuredGrid()
    { SetDataSetTypeToStructuredGrid_7(); }

  private native void SetDataSetTypeToRectilinearGrid_8();
  public void SetDataSetTypeToRectilinearGrid()
    { SetDataSetTypeToRectilinearGrid_8(); }

  private native void SetDataSetTypeToUnstructuredGrid_9();
  public void SetDataSetTypeToUnstructuredGrid()
    { SetDataSetTypeToUnstructuredGrid_9(); }

  private native long GetOutput_10();
  public vtkDataSet GetOutput() {
    long temp = GetOutput_10();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_11(int id0);
  public vtkDataSet GetOutput(int id0) {
    long temp = GetOutput_11(id0);

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPolyDataOutput_12();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_12();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_13();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_13();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_14();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_14();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_15();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_15();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_16();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_16();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPointComponent_17(int id0,String id1,int id2,int id3,int id4,int id5);
  public void SetPointComponent(int id0,String id1,int id2,int id3,int id4,int id5)
    { SetPointComponent_17(id0,id1,id2,id3,id4,id5); }

  private native void SetPointComponent_18(int id0,String id1,int id2);
  public void SetPointComponent(int id0,String id1,int id2)
    { SetPointComponent_18(id0,id1,id2); }

  private native String GetPointComponentArrayName_19(int id0);
  public String GetPointComponentArrayName(int id0)
    { return GetPointComponentArrayName_19(id0); }

  private native int GetPointComponentArrayComponent_20(int id0);
  public int GetPointComponentArrayComponent(int id0)
    { return GetPointComponentArrayComponent_20(id0); }

  private native int GetPointComponentMinRange_21(int id0);
  public int GetPointComponentMinRange(int id0)
    { return GetPointComponentMinRange_21(id0); }

  private native int GetPointComponentMaxRange_22(int id0);
  public int GetPointComponentMaxRange(int id0)
    { return GetPointComponentMaxRange_22(id0); }

  private native int GetPointComponentNormailzeFlag_23(int id0);
  public int GetPointComponentNormailzeFlag(int id0)
    { return GetPointComponentNormailzeFlag_23(id0); }

  private native void SetVertsComponent_24(String id0,int id1,int id2,int id3);
  public void SetVertsComponent(String id0,int id1,int id2,int id3)
    { SetVertsComponent_24(id0,id1,id2,id3); }

  private native void SetVertsComponent_25(String id0,int id1);
  public void SetVertsComponent(String id0,int id1)
    { SetVertsComponent_25(id0,id1); }

  private native String GetVertsComponentArrayName_26();
  public String GetVertsComponentArrayName()
    { return GetVertsComponentArrayName_26(); }

  private native int GetVertsComponentArrayComponent_27();
  public int GetVertsComponentArrayComponent()
    { return GetVertsComponentArrayComponent_27(); }

  private native int GetVertsComponentMinRange_28();
  public int GetVertsComponentMinRange()
    { return GetVertsComponentMinRange_28(); }

  private native int GetVertsComponentMaxRange_29();
  public int GetVertsComponentMaxRange()
    { return GetVertsComponentMaxRange_29(); }

  private native void SetLinesComponent_30(String id0,int id1,int id2,int id3);
  public void SetLinesComponent(String id0,int id1,int id2,int id3)
    { SetLinesComponent_30(id0,id1,id2,id3); }

  private native void SetLinesComponent_31(String id0,int id1);
  public void SetLinesComponent(String id0,int id1)
    { SetLinesComponent_31(id0,id1); }

  private native String GetLinesComponentArrayName_32();
  public String GetLinesComponentArrayName()
    { return GetLinesComponentArrayName_32(); }

  private native int GetLinesComponentArrayComponent_33();
  public int GetLinesComponentArrayComponent()
    { return GetLinesComponentArrayComponent_33(); }

  private native int GetLinesComponentMinRange_34();
  public int GetLinesComponentMinRange()
    { return GetLinesComponentMinRange_34(); }

  private native int GetLinesComponentMaxRange_35();
  public int GetLinesComponentMaxRange()
    { return GetLinesComponentMaxRange_35(); }

  private native void SetPolysComponent_36(String id0,int id1,int id2,int id3);
  public void SetPolysComponent(String id0,int id1,int id2,int id3)
    { SetPolysComponent_36(id0,id1,id2,id3); }

  private native void SetPolysComponent_37(String id0,int id1);
  public void SetPolysComponent(String id0,int id1)
    { SetPolysComponent_37(id0,id1); }

  private native String GetPolysComponentArrayName_38();
  public String GetPolysComponentArrayName()
    { return GetPolysComponentArrayName_38(); }

  private native int GetPolysComponentArrayComponent_39();
  public int GetPolysComponentArrayComponent()
    { return GetPolysComponentArrayComponent_39(); }

  private native int GetPolysComponentMinRange_40();
  public int GetPolysComponentMinRange()
    { return GetPolysComponentMinRange_40(); }

  private native int GetPolysComponentMaxRange_41();
  public int GetPolysComponentMaxRange()
    { return GetPolysComponentMaxRange_41(); }

  private native void SetStripsComponent_42(String id0,int id1,int id2,int id3);
  public void SetStripsComponent(String id0,int id1,int id2,int id3)
    { SetStripsComponent_42(id0,id1,id2,id3); }

  private native void SetStripsComponent_43(String id0,int id1);
  public void SetStripsComponent(String id0,int id1)
    { SetStripsComponent_43(id0,id1); }

  private native String GetStripsComponentArrayName_44();
  public String GetStripsComponentArrayName()
    { return GetStripsComponentArrayName_44(); }

  private native int GetStripsComponentArrayComponent_45();
  public int GetStripsComponentArrayComponent()
    { return GetStripsComponentArrayComponent_45(); }

  private native int GetStripsComponentMinRange_46();
  public int GetStripsComponentMinRange()
    { return GetStripsComponentMinRange_46(); }

  private native int GetStripsComponentMaxRange_47();
  public int GetStripsComponentMaxRange()
    { return GetStripsComponentMaxRange_47(); }

  private native void SetCellTypeComponent_48(String id0,int id1,int id2,int id3);
  public void SetCellTypeComponent(String id0,int id1,int id2,int id3)
    { SetCellTypeComponent_48(id0,id1,id2,id3); }

  private native void SetCellTypeComponent_49(String id0,int id1);
  public void SetCellTypeComponent(String id0,int id1)
    { SetCellTypeComponent_49(id0,id1); }

  private native String GetCellTypeComponentArrayName_50();
  public String GetCellTypeComponentArrayName()
    { return GetCellTypeComponentArrayName_50(); }

  private native int GetCellTypeComponentArrayComponent_51();
  public int GetCellTypeComponentArrayComponent()
    { return GetCellTypeComponentArrayComponent_51(); }

  private native int GetCellTypeComponentMinRange_52();
  public int GetCellTypeComponentMinRange()
    { return GetCellTypeComponentMinRange_52(); }

  private native int GetCellTypeComponentMaxRange_53();
  public int GetCellTypeComponentMaxRange()
    { return GetCellTypeComponentMaxRange_53(); }

  private native void SetCellConnectivityComponent_54(String id0,int id1,int id2,int id3);
  public void SetCellConnectivityComponent(String id0,int id1,int id2,int id3)
    { SetCellConnectivityComponent_54(id0,id1,id2,id3); }

  private native void SetCellConnectivityComponent_55(String id0,int id1);
  public void SetCellConnectivityComponent(String id0,int id1)
    { SetCellConnectivityComponent_55(id0,id1); }

  private native String GetCellConnectivityComponentArrayName_56();
  public String GetCellConnectivityComponentArrayName()
    { return GetCellConnectivityComponentArrayName_56(); }

  private native int GetCellConnectivityComponentArrayComponent_57();
  public int GetCellConnectivityComponentArrayComponent()
    { return GetCellConnectivityComponentArrayComponent_57(); }

  private native int GetCellConnectivityComponentMinRange_58();
  public int GetCellConnectivityComponentMinRange()
    { return GetCellConnectivityComponentMinRange_58(); }

  private native int GetCellConnectivityComponentMaxRange_59();
  public int GetCellConnectivityComponentMaxRange()
    { return GetCellConnectivityComponentMaxRange_59(); }

  private native void SetDefaultNormalize_60(int id0);
  public void SetDefaultNormalize(int id0)
    { SetDefaultNormalize_60(id0); }

  private native int GetDefaultNormalize_61();
  public int GetDefaultNormalize()
    { return GetDefaultNormalize_61(); }

  private native void DefaultNormalizeOn_62();
  public void DefaultNormalizeOn()
    { DefaultNormalizeOn_62(); }

  private native void DefaultNormalizeOff_63();
  public void DefaultNormalizeOff()
    { DefaultNormalizeOff_63(); }

  private native void SetDimensions_64(int id0,int id1,int id2);
  public void SetDimensions(int id0,int id1,int id2)
    { SetDimensions_64(id0,id1,id2); }

  private native void SetDimensions_65(int id0[]);
  public void SetDimensions(int id0[])
    { SetDimensions_65(id0); }

  private native int[]  GetDimensions_66();
  public int[]  GetDimensions()
    { return GetDimensions_66(); }

  private native void SetOrigin_67(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_67(id0,id1,id2); }

  private native void SetOrigin_68(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_68(id0); }

  private native double[] GetOrigin_69();
  public double[] GetOrigin()
    { return GetOrigin_69(); }

  private native void SetSpacing_70(double id0,double id1,double id2);
  public void SetSpacing(double id0,double id1,double id2)
    { SetSpacing_70(id0,id1,id2); }

  private native void SetSpacing_71(double id0[]);
  public void SetSpacing(double id0[])
    { SetSpacing_71(id0); }

  private native double[] GetSpacing_72();
  public double[] GetSpacing()
    { return GetSpacing_72(); }

  private native void SetDimensionsComponent_73(String id0,int id1,int id2,int id3);
  public void SetDimensionsComponent(String id0,int id1,int id2,int id3)
    { SetDimensionsComponent_73(id0,id1,id2,id3); }

  private native void SetDimensionsComponent_74(String id0,int id1);
  public void SetDimensionsComponent(String id0,int id1)
    { SetDimensionsComponent_74(id0,id1); }

  private native void SetSpacingComponent_75(String id0,int id1,int id2,int id3);
  public void SetSpacingComponent(String id0,int id1,int id2,int id3)
    { SetSpacingComponent_75(id0,id1,id2,id3); }

  private native void SetSpacingComponent_76(String id0,int id1);
  public void SetSpacingComponent(String id0,int id1)
    { SetSpacingComponent_76(id0,id1); }

  private native void SetOriginComponent_77(String id0,int id1,int id2,int id3);
  public void SetOriginComponent(String id0,int id1,int id2,int id3)
    { SetOriginComponent_77(id0,id1,id2,id3); }

  private native void SetOriginComponent_78(String id0,int id1);
  public void SetOriginComponent(String id0,int id1)
    { SetOriginComponent_78(id0,id1); }

  public vtkDataObjectToDataSetFilter() { super(); }

  public vtkDataObjectToDataSetFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkDataObjectToDataSetFilter.java <==
// java wrapper for vtkDataObjectToDataSetFilter object
//

package vtk;
import vtk.*;

public class vtkDataObjectToDataSetFilter extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkDataObject GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDataSetType_3(int id0);
  public void SetDataSetType(int id0)
    { SetDataSetType_3(id0); }

  private native int GetDataSetType_4();
  public int GetDataSetType()
    { return GetDataSetType_4(); }

  private native void SetDataSetTypeToPolyData_5();
  public void SetDataSetTypeToPolyData()
    { SetDataSetTypeToPolyData_5(); }

  private native void SetDataSetTypeToStructuredPoints_6();
  public void SetDataSetTypeToStructuredPoints()
    { SetDataSetTypeToStructuredPoints_6(); }

  private native void SetDataSetTypeToStructuredGrid_7();
  public void SetDataSetTypeToStructuredGrid()
    { SetDataSetTypeToStructuredGrid_7(); }

  private native void SetDataSetTypeToRectilinearGrid_8();
  public void SetDataSetTypeToRectilinearGrid()
    { SetDataSetTypeToRectilinearGrid_8(); }

  private native void SetDataSetTypeToUnstructuredGrid_9();
  public void SetDataSetTypeToUnstructuredGrid()
    { SetDataSetTypeToUnstructuredGrid_9(); }

  private native long GetOutput_10();
  public vtkDataSet GetOutput() {
    long temp = GetOutput_10();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_11(int id0);
  public vtkDataSet GetOutput(int id0) {
    long temp = GetOutput_11(id0);

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPolyDataOutput_12();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_12();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_13();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_13();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_14();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_14();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_15();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_15();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_16();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_16();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPointComponent_17(int id0,String id1,int id2,int id3,int id4,int id5);
  public void SetPointComponent(int id0,String id1,int id2,int id3,int id4,int id5)
    { SetPointComponent_17(id0,id1,id2,id3,id4,id5); }

  private native void SetPointComponent_18(int id0,String id1,int id2);
  public void SetPointComponent(int id0,String id1,int id2)
    { SetPointComponent_18(id0,id1,id2); }

  private native String GetPointComponentArrayName_19(int id0);
  public String GetPointComponentArrayName(int id0)
    { return GetPointComponentArrayName_19(id0); }

  private native int GetPointComponentArrayComponent_20(int id0);
  public int GetPointComponentArrayComponent(int id0)
    { return GetPointComponentArrayComponent_20(id0); }

  private native int GetPointComponentMinRange_21(int id0);
  public int GetPointComponentMinRange(int id0)
    { return GetPointComponentMinRange_21(id0); }

  private native int GetPointComponentMaxRange_22(int id0);
  public int GetPointComponentMaxRange(int id0)
    { return GetPointComponentMaxRange_22(id0); }

  private native int GetPointComponentNormailzeFlag_23(int id0);
  public int GetPointComponentNormailzeFlag(int id0)
    { return GetPointComponentNormailzeFlag_23(id0); }

  private native void SetVertsComponent_24(String id0,int id1,int id2,int id3);
  public void SetVertsComponent(String id0,int id1,int id2,int id3)
    { SetVertsComponent_24(id0,id1,id2,id3); }

  private native void SetVertsComponent_25(String id0,int id1);
  public void SetVertsComponent(String id0,int id1)
    { SetVertsComponent_25(id0,id1); }

  private native String GetVertsComponentArrayName_26();
  public String GetVertsComponentArrayName()
    { return GetVertsComponentArrayName_26(); }

  private native int GetVertsComponentArrayComponent_27();
  public int GetVertsComponentArrayComponent()
    { return GetVertsComponentArrayComponent_27(); }

  private native int GetVertsComponentMinRange_28();
  public int GetVertsComponentMinRange()
    { return GetVertsComponentMinRange_28(); }

  private native int GetVertsComponentMaxRange_29();
  public int GetVertsComponentMaxRange()
    { return GetVertsComponentMaxRange_29(); }

  private native void SetLinesComponent_30(String id0,int id1,int id2,int id3);
  public void SetLinesComponent(String id0,int id1,int id2,int id3)
    { SetLinesComponent_30(id0,id1,id2,id3); }

  private native void SetLinesComponent_31(String id0,int id1);
  public void SetLinesComponent(String id0,int id1)
    { SetLinesComponent_31(id0,id1); }

  private native String GetLinesComponentArrayName_32();
  public String GetLinesComponentArrayName()
    { return GetLinesComponentArrayName_32(); }

  private native int GetLinesComponentArrayComponent_33();
  public int GetLinesComponentArrayComponent()
    { return GetLinesComponentArrayComponent_33(); }

  private native int GetLinesComponentMinRange_34();
  public int GetLinesComponentMinRange()
    { return GetLinesComponentMinRange_34(); }

  private native int GetLinesComponentMaxRange_35();
  public int GetLinesComponentMaxRange()
    { return GetLinesComponentMaxRange_35(); }

  private native void SetPolysComponent_36(String id0,int id1,int id2,int id3);
  public void SetPolysComponent(String id0,int id1,int id2,int id3)
    { SetPolysComponent_36(id0,id1,id2,id3); }

  private native void SetPolysComponent_37(String id0,int id1);
  public void SetPolysComponent(String id0,int id1)
    { SetPolysComponent_37(id0,id1); }

  private native String GetPolysComponentArrayName_38();
  public String GetPolysComponentArrayName()
    { return GetPolysComponentArrayName_38(); }

  private native int GetPolysComponentArrayComponent_39();
  public int GetPolysComponentArrayComponent()
    { return GetPolysComponentArrayComponent_39(); }

  private native int GetPolysComponentMinRange_40();
  public int GetPolysComponentMinRange()
    { return GetPolysComponentMinRange_40(); }

  private native int GetPolysComponentMaxRange_41();
  public int GetPolysComponentMaxRange()
    { return GetPolysComponentMaxRange_41(); }

  private native void SetStripsComponent_42(String id0,int id1,int id2,int id3);
  public void SetStripsComponent(String id0,int id1,int id2,int id3)
    { SetStripsComponent_42(id0,id1,id2,id3); }

  private native void SetStripsComponent_43(String id0,int id1);
  public void SetStripsComponent(String id0,int id1)
    { SetStripsComponent_43(id0,id1); }

  private native String GetStripsComponentArrayName_44();
  public String GetStripsComponentArrayName()
    { return GetStripsComponentArrayName_44(); }

  private native int GetStripsComponentArrayComponent_45();
  public int GetStripsComponentArrayComponent()
    { return GetStripsComponentArrayComponent_45(); }

  private native int GetStripsComponentMinRange_46();
  public int GetStripsComponentMinRange()
    { return GetStripsComponentMinRange_46(); }

  private native int GetStripsComponentMaxRange_47();
  public int GetStripsComponentMaxRange()
    { return GetStripsComponentMaxRange_47(); }

  private native void SetCellTypeComponent_48(String id0,int id1,int id2,int id3);
  public void SetCellTypeComponent(String id0,int id1,int id2,int id3)
    { SetCellTypeComponent_48(id0,id1,id2,id3); }

  private native void SetCellTypeComponent_49(String id0,int id1);
  public void SetCellTypeComponent(String id0,int id1)
    { SetCellTypeComponent_49(id0,id1); }

  private native String GetCellTypeComponentArrayName_50();
  public String GetCellTypeComponentArrayName()
    { return GetCellTypeComponentArrayName_50(); }

  private native int GetCellTypeComponentArrayComponent_51();
  public int GetCellTypeComponentArrayComponent()
    { return GetCellTypeComponentArrayComponent_51(); }

  private native int GetCellTypeComponentMinRange_52();
  public int GetCellTypeComponentMinRange()
    { return GetCellTypeComponentMinRange_52(); }

  private native int GetCellTypeComponentMaxRange_53();
  public int GetCellTypeComponentMaxRange()
    { return GetCellTypeComponentMaxRange_53(); }

  private native void SetCellConnectivityComponent_54(String id0,int id1,int id2,int id3);
  public void SetCellConnectivityComponent(String id0,int id1,int id2,int id3)
    { SetCellConnectivityComponent_54(id0,id1,id2,id3); }

  private native void SetCellConnectivityComponent_55(String id0,int id1);
  public void SetCellConnectivityComponent(String id0,int id1)
    { SetCellConnectivityComponent_55(id0,id1); }

  private native String GetCellConnectivityComponentArrayName_56();
  public String GetCellConnectivityComponentArrayName()
    { return GetCellConnectivityComponentArrayName_56(); }

  private native int GetCellConnectivityComponentArrayComponent_57();
  public int GetCellConnectivityComponentArrayComponent()
    { return GetCellConnectivityComponentArrayComponent_57(); }

  private native int GetCellConnectivityComponentMinRange_58();
  public int GetCellConnectivityComponentMinRange()
    { return GetCellConnectivityComponentMinRange_58(); }

  private native int GetCellConnectivityComponentMaxRange_59();
  public int GetCellConnectivityComponentMaxRange()
    { return GetCellConnectivityComponentMaxRange_59(); }

  private native void SetDefaultNormalize_60(int id0);
  public void SetDefaultNormalize(int id0)
    { SetDefaultNormalize_60(id0); }

  private native int GetDefaultNormalize_61();
  public int GetDefaultNormalize()
    { return GetDefaultNormalize_61(); }

  private native void DefaultNormalizeOn_62();
  public void DefaultNormalizeOn()
    { DefaultNormalizeOn_62(); }

  private native void DefaultNormalizeOff_63();
  public void DefaultNormalizeOff()
    { DefaultNormalizeOff_63(); }

  private native void SetDimensions_64(int id0,int id1,int id2);
  public void SetDimensions(int id0,int id1,int id2)
    { SetDimensions_64(id0,id1,id2); }

  private native void SetDimensions_65(int id0[]);
  public void SetDimensions(int id0[])
    { SetDimensions_65(id0); }

  private native int[]  GetDimensions_66();
  public int[]  GetDimensions()
    { return GetDimensions_66(); }

  private native void SetOrigin_67(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_67(id0,id1,id2); }

  private native void SetOrigin_68(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_68(id0); }

  private native double[] GetOrigin_69();
  public double[] GetOrigin()
    { return GetOrigin_69(); }

  private native void SetSpacing_70(double id0,double id1,double id2);
  public void SetSpacing(double id0,double id1,double id2)
    { SetSpacing_70(id0,id1,id2); }

  private native void SetSpacing_71(double id0[]);
  public void SetSpacing(double id0[])
    { SetSpacing_71(id0); }

  private native double[] GetSpacing_72();
  public double[] GetSpacing()
    { return GetSpacing_72(); }

  private native void SetDimensionsComponent_73(String id0,int id1,int id2,int id3);
  public void SetDimensionsComponent(String id0,int id1,int id2,int id3)
    { SetDimensionsComponent_73(id0,id1,id2,id3); }

  private native void SetDimensionsComponent_74(String id0,int id1);
  public void SetDimensionsComponent(String id0,int id1)
    { SetDimensionsComponent_74(id0,id1); }

  private native void SetSpacingComponent_75(String id0,int id1,int id2,int id3);
  public void SetSpacingComponent(String id0,int id1,int id2,int id3)
    { SetSpacingComponent_75(id0,id1,id2,id3); }

  private native void SetSpacingComponent_76(String id0,int id1);
  public void SetSpacingComponent(String id0,int id1)
    { SetSpacingComponent_76(id0,id1); }

  private native void SetOriginComponent_77(String id0,int id1,int id2,int id3);
  public void SetOriginComponent(String id0,int id1,int id2,int id3)
    { SetOriginComponent_77(id0,id1,id2,id3); }

  private native void SetOriginComponent_78(String id0,int id1);
  public void SetOriginComponent(String id0,int id1)
    { SetOriginComponent_78(id0,id1); }

  public vtkDataObjectToDataSetFilter() { super(); }

  public vtkDataObjectToDataSetFilter(long id) { super(id); }
  public native long   VTKInit();

}
